<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use App\Models\BagmanifestDetail;
use App\Models\BagmanifestSummary;
use App\Models\Booking;
use App\Models\Branch;
use App\Models\BranchAsignCity;
use App\Models\CityModel;
use App\Models\CountryModel;
use App\Models\customer;
use App\Models\Service;
use App\Models\Staff;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Validator;
use Yajra\DataTables\Facades\DataTables;

class Bagmanifest extends Controller
{
    private $i;
    private $x;
    private $count;
    public function index()
    {
        $countries = CountryModel::where('status', 1)->get();
        $cities = CityModel::where('status', 1)->get();
        $getservices = Service::where('status', 1)->get();
        $customer = customer::where('status', 1)->get();
        $branches = Branch::where('status', 1)->get();
        $status = DB::table('shipment_status')->get();
        return view('admin.bagmanifest.index_selection')->with(compact('countries', 'getservices', 'cities', 'customer', 'branches', 'status'));
    }

    public function nextstep()
    {
        $countries = CountryModel::where('status', 1)->get();
        $cities = CityModel::where('status', 1)->get();
        $getservices = Service::where('status', 1)->get();
        $customer = customer::where('status', 1)->get();
        $branches = Branch::where('status', 1)->get();
        $status = DB::table('shipment_status')->get();
        $getstaff = Staff::where('status', 1)->get();
        return view('admin.bagmanifest.index')->with(compact('countries', 'getservices', 'cities', 'customer', 'branches', 'status', 'getstaff'));
    }

    public function show($orign_filter = NULL, $destination_filter = NULL, $branch_filter = NULL, $reservation = NULL)
    {
        try {
            $bagmanifest = DB::table('shipment_booking as sb')
                ->join('customers as cus', 'cus.id', '=', 'sb.consignor_id')
                ->join('city as c_city', 'c_city.id', '=', 'sb.consignor_city')
                ->join('city', 'city.id', '=', 'sb.consignee_city')
                ->join('services as s', 's.id', '=', 'sb.service_id');
            // ->join('shipment_status as ss', 'ss.status_id', '=', 'sb.parcel_last_status', 'left');

            if ($orign_filter != null && $orign_filter != 0)
                $bagmanifest->whereIn('cus.city_id', [$orign_filter]);

            if ($destination_filter != null && $destination_filter != 0)
                $bagmanifest->whereIn('sb.consignee_city', [$destination_filter]);

            if ($branch_filter != null && $branch_filter != 0) {
                $city_list = BranchAsignCity::wherein('branch_id', [$branch_filter])->select('city_id')->get();
                $branch_city_filter = "";
                foreach ($city_list as $city) {
                    if ($branch_city_filter == "")
                        $branch_city_filter = $branch_city_filter . "" . $city->city_id . "";
                    else
                        $branch_city_filter = $branch_city_filter . "," . $city->city_id . "";
                }

                $bagmanifest->whereIn('sb.consignee_city', [$branch_city_filter]);
            }

            $from_date = "";
            $to_date = "";
            $date_range = $reservation;
            if (!empty($date_range)) {
                $iparr = explode("|", trim($date_range));
                $from_date = trim($iparr[0]);
                $to_date = trim($iparr[1]);
            }

            $bagmanifest->whereBetween('sb.booking_date', [$from_date, $to_date]);
            $bagmanifest->where('sb.parcel_last_status', '!=', '');
            $bagmanifest->where('sb.is_bagmanifest', '=', '0');
            $bagmanifest->whereNotIn('sb.id', DB::table('temp_table')->where('document', '=', 'BAGMANIFEST')->pluck('cn_no'));
            $bagmanifest->orderBy('sb.pickup_date', 'asc');

            $bagmanifest->select(
                'sb.id as cn_no',
                'sb.booking_date',
                'sb.pickup_date',
                'sb.customer_type',
                'sb.consignee_name',
                'sb.consignee_city',
                'sb.parcel_actual_weight',
                'sb.consignor_id',
                'sb.cod_amount',
                'city.name as destination',
                'cus.customer_name',
                'c_city.name as consignor_city'
            )->get();
            return DataTables::of($bagmanifest)
                ->addColumn('checkbox', function ($data) {
                    return checkbox_show($data->cn_no);
                })
                ->addColumn('pcs', function ($data) {
                    return '<input type="text" cn_no="' . $data->cn_no . '" readonly class="form_control pcs"  name="pcs"  value="1" >';
                })
                ->rawColumns(['checkbox', 'pcs'])
                ->make(true);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function addBMTempTable(Request $request)
    {
        if ($request->ajax()) {
            $validator = Validator::make($request->all(), [
                'check_all' => 'required'
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }

            foreach ($request->check_all as $value) {
                DB::table('temp_table')->insert([
                    'cn_no' => $value,
                    'document' => "BAGMANIFEST",
                    'user_entry' => Auth::User()->id,
                    'user_modify' => Auth::User()->id,
                    'created_at' => getCurrentDateTime(),
                    'updated_at' => getCurrentDateTime()
                ]);
            }
            return response()->json(['Bagmanifest Record Add successfully'], 200);
        }
        return 'false';
    }

    public function sealMaxNumber()
    {
        try {
            $max = BagmanifestSummary::max('id');
            if ($max == null)
                $max = 0;
            return response()->json(['success' => 'successfull retrieve data', 'data' => $max], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function showTempRecord()
    {
        try {
            $this->x = 0;
            $this->i = 0;
            $bagmanifest = DB::table('shipment_booking as sb')
                ->join('customers as cus', 'cus.id', '=', 'sb.consignor_id')
                ->join('city as c_city', 'c_city.id', '=', 'sb.consignor_city')
                ->join('city', 'city.id', '=', 'sb.consignee_city')
                ->join('services as s', 's.id', '=', 'sb.service_id')
                ->where('sb.parcel_last_status', '!=', '')
                ->where('sb.is_bagmanifest', '=', '0')
                ->whereIn('sb.id', DB::table('temp_table')->where('document', '=', 'BAGMANIFEST')->pluck('cn_no'))
                ->orderBy('sb.pickup_date', 'asc')
                ->select(
                    'sb.is_bagmanifest',
                    'sb.id as cn_no',
                    'sb.booking_date',
                    'sb.pickup_date',
                    'sb.customer_type',
                    'sb.consignee_name',
                    'sb.consignee_city',
                    'sb.parcel_actual_weight',
                    'sb.consignor_id',
                    'sb.consignor_city as orign',
                    'sb.parcel_last_status',
                    'sb.cod_amount',
                    'city.name as destination',
                    'cus.customer_name',
                    'c_city.name as consignor_city',
                    'sb.service_id'
                )->get();
            $this->count = count($bagmanifest);
            return DataTables::of($bagmanifest)
                ->addColumn('checkbox', function ($data) {
                    $this->i++;
                    return '<input type="checkbox" class="chk_del"  name="chk_del_' . $this->i . '" value="' . $data->cn_no . '" >';
                })
                ->addColumn('pcs', function ($data) {
                    $this->x++;
                    return '<input type="hidden" name="totalnum" value="' . $this->count . '" />
                    <input type="text"   class="form_control pcs"  name="pcs_' . $this->x . '"  value="1" >
                    <input type="hidden" name="pickup_date_' . $this->x . '"  value="' . $data->pickup_date . '" />
                    <input type="hidden" name="consignor_name_' . $this->x . '"  value="' . $data->customer_name . '" />
                    <input type="hidden" name="consignor_id_' . $this->x . '"  value="' . $data->consignor_id . '" />
                    <input type="hidden" name="consignee_name_' . $this->x . '"  value="' . $data->consignee_name . '" />
                    <input type="hidden" name="orign_' . $this->x . '"  value="' . $data->orign . '" />
                    <input type="hidden" name="destination_' . $this->x . '"  value="' . $data->consignee_city . '" />
                    <input type="hidden" name="weight_' . $this->x . '" id="weight' . $this->x . '" value="' . $data->parcel_actual_weight . '" />
                    <input type="hidden" name="cod_amount_' . $this->x . '" id="cod_amount' . $this->x . '" value=" ' . $data->cod_amount . ' " />
                    <input type="hidden" name="service_type_' . $this->x . '" value=" ' . $data->service_id . ' " />
                    <input type="hidden" name="status_' . $this->x . '" value=" ' . $data->parcel_last_status . ' " />';
                })
                ->addIndexColumn()
                ->rawColumns(['checkbox', 'pcs', 'DT_RowIndex'])
                ->make(true);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function addBM(Request $request)
    {
        if ($request->ajax()) {
            $validator = Validator::make($request->all(), [
                'seal' => 'required|numeric',
                'mode' => 'required',
                'staff_id' => 'required|numeric',
                'total_bag' => 'required|numeric',
                'total_pieces' => 'required|numeric',
                'total_weight' => 'required|numeric',
                'total_cod' => 'required|numeric',
                'total_parcels' => 'required|numeric',
                'time_ops' => 'required',
                'sign_ops' => 'required',
            ]);

            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }
            if ($request->totalnum > 0) {
                $bagSummary = new BagmanifestSummary;
                $bagSummary->id =  $request->seal;
                $bagSummary->mode = $request->mode;
                $bagSummary->staff_id = $request->staff_id;
                $bagSummary->total_bag = $request->total_bag;
                $bagSummary->total_pieces = $request->total_pieces;
                $bagSummary->total_weight = $request->total_weight;
                $bagSummary->total_cod_amount = $request->total_cod;
                $bagSummary->total_parcels = $request->total_parcels;
                $bagSummary->time_ops = $request->time_ops;
                $bagSummary->sign_ops = $request->sign_ops;
                $bagSummary->entry_date = getCurrentDate();
                $bagSummary->user_entry = Auth::User()->id;
                $bagSummary->user_modify = Auth::User()->id;
                $bagSummary->save();
            }
            $i = 1;
            while ($i <= $request->totalnum) {
                if (!empty($request->post('chk_del_' . $i))) {
                    $bagDetail = new BagmanifestDetail;
                    $bagDetail->seal = $request->seal;
                    $bagDetail->cn_no = $request->post('chk_del_' . $i);
                    $bagDetail->consignor_id = $request->post('consignor_id_' . $i);
                    $bagDetail->consignor_name = $request->post('consignor_name_' . $i);
                    $bagDetail->consignee_name = $request->post('consignee_name_' . $i);
                    $bagDetail->orign = $request->post('orign_' . $i);
                    $bagDetail->destination = $request->post('destination_' . $i);
                    $bagDetail->weight = $request->post('weight_' . $i);
                    $bagDetail->cod_amount = $request->post('cod_amount_' . $i);
                    $bagDetail->pcs = $request->post('pcs_' . $i);
                    $bagDetail->pickup_date = $request->post('pickup_date_' . $i);
                    $bagDetail->service_type = $request->post('service_type_' . $i);
                    $bagDetail->status = $request->post('status_' . $i);
                    $bagDetail->user_entry = Auth::User()->id;
                    $bagDetail->user_modify = Auth::User()->id;
                    $bagDetail->save();

                    $booking = Booking::findOrFail($request->post('chk_del_' . $i));
                    $booking->is_bagmanifest  = 1;
                    $booking->user_modify = Auth::User()->id;
                    $booking->update();
                }
                $i++;
            }

            DB::table('temp_table')
                ->where('user_entry', Auth::User()->id)
                ->where('document', "BAGMANIFEST")->delete();

            return response()->json(['success' => 'data is successfully updated'], 200);
        }
        //return 'false';
    }


    //report section  start
    public function BagmanifestReport()
    {
        $branches = Branch::where('status', 1)->get();
        return view('admin.bagmanifest.report')->with(compact('branches'));
    }

    public function getSealNo(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'branch_id' => 'required'
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }

            $bagmanifest = DB::table('bagmanifest_summary as bs')
                ->join('bagmanifest_detail as bd', 'bd.seal', '=', 'bs.id');

            $branch_filter = "";
            if (!empty($request->branch_id)) {
                foreach ($request->branch_id as $branch) {
                    if ($branch_filter == "")
                        $branch_filter = $branch_filter . "" . $branch . "";
                    else
                        $branch_filter = $branch_filter . "," . $branch . "";
                }
            }

            if ($branch_filter != null && $branch_filter != 0) {
                $branch_ids = explode(",", branch_filter($branch_filter));
                $bagmanifest = $bagmanifest->whereIn('bd.destination', $branch_ids);
            }

            $reservation = $request->date_range;
            $from_date = "";
            $to_date = "";
            $date_range = $reservation;
            if (!empty($date_range)) {
                $iparr = explode("|", trim($date_range));
                $from_date = trim($iparr[0]);
                $to_date = trim($iparr[1]);
            }

            $bagmanifest = $bagmanifest->whereBetween('bs.entry_date', [$from_date, $to_date]);
            $bagmanifest = $bagmanifest->select('bs.id as seal')->distinct()->get();
            $msg['bagmanifest'] = $bagmanifest->toJson();
            return response()->json(['success' => 'successfull retrieve data', $msg], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }


    public function getBagmanifestReport(Request $request)
    {
        try {

            $bag_detail = DB::table('bagmanifest_detail as bd')
                ->join('customers as cus', 'cus.id', '=', 'bd.consignor_id', 'left')
                ->join('city', 'city.id', '=', 'bd.destination', 'left')
                ->join('city as c_city', 'c_city.id', '=', 'bd.orign', 'left');

            if (!empty($request->seal_no) && $request->seal_no != null) {
                $bag_detail = $bag_detail->where('bd.seal', '=', $request->seal_no);
            }

            if (!empty($request->cn_no) && $request->cn_no != null) {
                $bag_detail = $bag_detail->where('bd.cn_no', '=', $request->cn_no);
            }

            $branch_filter = $request->branch_id;
            if ($branch_filter != null && $branch_filter != 0) {
                $branch_ids = explode(",", branch_filter($branch_filter));
                $bag_detail = $bag_detail->whereIn('bd.destination', $branch_ids);
            }

            $from_date = "";
            $to_date = "";
            $date_range = $request->date_range;
            if (!empty($date_range)) {
                $iparr = explode("|", trim($date_range));
                $from_date = trim($iparr[0]);
                $to_date = trim($iparr[1]);
            }

            $bag_detail = $bag_detail->whereBetween('bd.entry_date', [$from_date, $to_date]);

            $bag_detail = $bag_detail->select(
                'bd.id as id',
                'bd.seal as seal',
                'bd.cn_no as cn_no',
                'bd.consignor_id as consignor_id',
                'bd.consignor_name as consignor_name',
                'bd.consignee_name as consignee_name',
                'bd.weight as weight',
                'bd.cod_amount as cod_amount',
                'bd.pcs as pcs',
                'bd.pickup_date as pickup_date',
                'city.id as consignee_city_id',
                'city.name as consignee_city_name',
                'c_city.id as consignor_city_id',
                'c_city.name as consignor_city_name'
            )->get();




            $html = "";
            $html .= '<table width="100%" class="table table-bordered">
                        <thead>
                            <tr>                                
                                <th>S.No</th>
                                <th>CN #</th>
                                <th>Date</th>
                                <th>From</th>
                                <th>To</th>
                                <th>Origin</th>
                                <th>Destination</th>
                                <th>Weight</th>
                                <th>PCS</th>
                                <th>COD</th>                               
                            </tr>
                        </thead>
                        <tbody>';


            $totalcod_amount = 0;
            $totalweight = 0;
            $totalpcs = 0;
            $i = 0;

            if (!empty($bag_detail)) {
                foreach ($bag_detail as $row) {
                    $totalweight += $row->weight;
                    $totalpcs += $row->pcs;
                    $totalcod_amount += $row->cod_amount;
                    $html .= "<tr>
                                <td> " . ($i += 1) . " </td>                                                  
                                <td> " . $row->cn_no . " </td>
                                <td> " . $row->pickup_date . " </td>
                                <td> " . $row->consignor_name . " </td>
                                <td> " . $row->consignee_name . " </td>
                                <td> " . $row->consignor_city_name . " </td>
                                <td> " . $row->consignee_city_name . " </td>
                                <td> " . $row->weight . " </td>
                                <td> " . $row->pcs . " </td>
                                <td> " . $row->cod_amount . " </td>                                
                            </tr>";
                }
            }


            $bag_summary = DB::table('bagmanifest_summary as bs')
            ->join('staff as s', 's.id', '=', 'bs.staff_id')
            ->where('bs.id', '=', $request->seal_no)
            ->select('bs.time_ops','bs.sign_ops','s.staff_name')->get();
           

            $html .= "</tbody>
                    </table>";

            $html .= '<div class="col-md-3">
                    <div class="form-group">
                        <label>Total P.Bags :</label>   
                        <label>'.$totalpcs.'</label>
                    </div>
                    <!-- /.form group -->
                </div>
                <div class="col-md-3">
                    <!-- Date range -->
                    <div class="form-group">
                        <label>Total COD Amount :</label>
                        <label>'.$totalcod_amount.'</label>
                    </div>
                    <!-- /.form group -->
                </div>

                <div class="col-md-3">
                    <div class="form-group">
                        <label>Total Parcels :</label>       
                        <label>'.$totalpcs.'</label>
                    </div>
                    <!-- /.form group -->
                </div>
                <div class="col-md-3">
                    <div class="form-group">
                        <label>Grand Total Pieces :</label>
                        <label>'.$totalpcs.' </label>                       
                    </div>
                    <!-- /.form group -->
                </div>

                <div class="col-md-3">
                    <!-- Date range -->
                    <div class="form-group">
                        <label>Grand Weight :</label>
                        <label>'.$totalweight.'</label>   
                    </div>
                    <!-- /.form group -->
                </div>

                <div class="col-md-4">

                    <div class="bootstrap-timepicker"> 
                        <div class="form-group">
                            <label>Dep:Time From OPS(ORG) : &nbsp;</label>
                            <label>'.(isset($bag_summary[0]->time_ops) ? $bag_summary[0]->time_ops : "") .'</label>   
                        </div>
                        <!-- /.form group -->
                    </div>
                    <!-- /.form group -->
                </div>

                <div class="col-md-4">
                    <div class="form-group">
                        <label>Sign. Of OPS Staff Out : &nbsp;</label>
                        <label>'. (isset($bag_summary[0]->sign_ops) ? $bag_summary[0]->sign_ops : "") .'</label>   
                    </div>
                    <!-- /.form group -->
                </div>';

            $msg['bag_detail'] = $html;
            $msg['date_from'] = $from_date;
            $msg['date_to'] = $to_date;
            $msg['staff_name'] = (isset($bag_summary[0]->staff_name) ? $bag_summary[0]->staff_name : "");
            return response()->json(['success' => 'successfull retrieve data', $msg], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    //report section end
}
