<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use App\Models\Branch;
use App\Models\BranchAsignCity;
use App\Models\CityModel;
use App\Models\CountryModel;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Yajra\DataTables\Facades\DataTables;
use Validator;

class BranchAsignCityController extends Controller
{
    public function index()
    {
        $countries = CountryModel::where('status', 1)->get();
        $cities = CityModel::where('status', 1)->get();
        $branches = Branch::where('status', 1)->get();
        return view('admin.branch_asign_city.index')->with(compact('countries', 'cities', 'branches'));
    }

    public function create()
    {
        try {
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }
    public function store(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [                
                'branch_id' => 'required|numeric',
                'country_id' => 'required|numeric',
                'city_id' => 'required',                
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }
            $status = 0;
            if($request->post('status') == "on")
            {
                $status = 1;
            }

            if (!empty($request->city_id)) {
                foreach ($request->city_id as $city) {
                    BranchAsignCity::create([
                        'branch_id' => $request->post('branch_id'),
                        'country_id' => $request->post('country_id'),
                        'city_id' => $city,
                        'status' => $status,
                        'user_entry' => \Auth::User()->id,
                        'user_modify' => \Auth::User()->id
                    ]);
                }
            }
            return response()->json(['success' => 'data is successfully updated'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function show($id)
    {
        try {
            //$branch = BranchAsignCity::select(['id', 'branch_id', 'country_id', 'city_id','status']);
            $branch = DB::table('branch_asign_city')
                ->join('branch', 'branch.id', '=', 'branch_asign_city.branch_id')
                ->join('country', 'country.id', '=', 'branch_asign_city.country_id')
                ->join('city', 'city.id', '=', 'branch_asign_city.city_id')
                ->select('branch_asign_city.*','branch.name as branch_name','country.name as country_name','city.name as city_name')->get();
            return DataTables::of($branch)
                ->addColumn('action', function ($data) {
                    return table_edit_delete_button($data->id, 'branch_asign_city');
                })
                ->addColumn('checkbox', function ($data) {
                    return checkbox_show($data->id);
                })
                ->editColumn('status', function ($data) {
                    return current_status($data->status);
                })   
                ->addIndexColumn()             
                ->rawColumns(['action', 'checkbox', 'status','DT_RowIndex'])
                ->make(true);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function edit($id)
    {
        try {
            $branch = BranchAsignCity::find($id);
            return response()->json(['success' => 'successfull retrieve data', 'data' => $branch->toJson()], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function rec_update(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'id' => 'required',
                'branch_id' => 'required|numeric',
                'country_id' => 'required|numeric',
                'citysingle' => 'required|numeric', 
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }
            $status = 0;
            if($request->status == "on")
            {
                $status = 1;
            }
            $branch = BranchAsignCity::findOrFail($request->id);                                               
            $branch->branch_id = $request->branch_id;
            $branch->country_id = $request->country_id;
            $branch->city_id = $request->citysingle;            
            $branch->status = $status;
            $branch->user_modify = \Auth::User()->id;
            $branch->update();
            return response()->json(['success' => 'data is successfully updated'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function destroy($id)
    {
        try {
            $branch = BranchAsignCity::find($id);
            $branch->delete();
            return response()->json(['success' => 'data is successfully deleted'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function deleteAll(Request $request)
    {
        if ($request->ajax()) {
            $validator = Validator::make($request->all(), [
                'check_all' => 'required'
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }

            foreach ($request->check_all as $value) {
                BranchAsignCity::where('id', $value)->delete();
            }
            return response()->json(['success' => 'data is successfully deleted'], 200);
        }
        return 'false';
    }
}