<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use App\Models\Booking;
use App\Models\Branch;
use App\Models\Charges;
use App\Models\CityModel;
use App\Models\CodBillDetail;
use App\Models\CodBillSummary;
use App\Models\CountryModel;
use App\Models\customer;
use App\Models\Service;
use App\Models\Staff;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Validator;
use Yajra\DataTables\Facades\DataTables;

class CodBillController extends Controller
{
    private $i;
    private $x;
    private $a;
    private $count;
    private $advance_amount;
    public function index()
    {
        $customer = customer::where('status', 1)->get();
        $cities = CityModel::where('status', 1)->get();
        return view('admin.codbill.index_selection')->with(compact('cities', 'customer'));
    }

    public function nextstep()
    {
        $countries = CountryModel::where('status', 1)->get();
        $cities = CityModel::where('status', 1)->get();
        $getservices = Service::where('status', 1)->get();
        $customer = customer::where('status', 1)->get();
        $branches = Branch::where('status', 1)->get();
        $status = DB::table('shipment_status')->get();
        $getstaff = Staff::where('status', 1)->get();
        return view('admin.codbill.index')->with(compact('countries', 'getservices', 'cities', 'customer', 'branches', 'status', 'getstaff'));
    }

    public function show($customer_filter = NULL, $destination_filter = NULL, $reservation = NULL)
    {
        try {
            $codbill = DB::table('shipment_booking as sb')
                ->join('customers as cus', 'cus.id', '=', 'sb.consignor_id')
                ->join('city as c_city', 'c_city.id', '=', 'sb.consignor_city')
                ->join('city', 'city.id', '=', 'sb.consignee_city')
                ->join('services as s', 's.id', '=', 'sb.service_id')
                ->join('shipment_status as ss', 'ss.status_id', '=', 'sb.parcel_last_status');

            if ($customer_filter != null && $customer_filter != 0)
                $codbill->where('sb.consignor_id', $customer_filter);

            if ($destination_filter != null && $destination_filter != 0)
                $codbill->whereIn('sb.consignee_city', [$destination_filter]);

            $from_date = "";
            $to_date = "";
            $date_range = $reservation;
            if (!empty($date_range)) {
                $iparr = explode("|", trim($date_range));
                $from_date = trim($iparr[0]);
                $to_date = trim($iparr[1]);
            }

            $codbill->whereBetween('sb.pickup_date', [$from_date, $to_date]);
            $codbill->where('sb.parcel_last_status', '!=', '1');
            $codbill->where('sb.is_codbill', '=', '0');
            $codbill->where('sb.is_delete', '=', '0');
            $codbill->whereNotIn('sb.id', DB::table('temp_table')->where('document', '=', 'CODBILL')->pluck('cn_no'));
            $codbill->orderBy('sb.pickup_date', 'asc');

            $codbill->select(
                'sb.id as cn_no',
                's.id as service_id',
                's.service_name',
                'sb.booking_date',
                'sb.pickup_date',
                'sb.customer_type',
                'sb.consignee_name',
                'sb.consignee_city',
                'sb.parcel_actual_weight',
                'sb.consignor_id',
                'sb.cod_amount',
                'city.name as destination',
                'cus.customer_name',
                'c_city.name as consignor_city',
                'sb.shipment_charges',
                'ss.status_name',
                'cus.return_charges',
                'sb.parcel_last_status'
            )->get();
            return DataTables::of($codbill)
                ->addColumn('checkbox', function ($data) {
                    return checkbox_show($data->cn_no);
                })
                ->addColumn('return_charges', function ($data) {
                    $status = $data->parcel_last_status;
                    $return_charges = 0;
                    if ($status == 6 || $status == 5 || $status == 9) {
                        if ($data->consignee_city == $data->consignor_city) {
                            $return_charges = 0;
                        } else {
                            $return_charges = $data->return_charges;
                        }
                    }
                    return $return_charges;
                })
                ->addColumn('payable', function ($data) {
                    $payable = 0;
                    $status = $data->parcel_last_status;
                    $return_charges = 0;
                    if ($status == 6 || $status == 5 || $status == 9) {
                        if ($data->consignee_city == $data->consignor_city) {
                            $return_charges = 0;
                        } else {
                            $return_charges = $data->return_charges;
                        }
                        $payable = $data->cod_amount - $data->shipment_charges - $return_charges;
                    }
                    return $payable;
                })
                ->addColumn('amount', function ($data) {
                    $payable = 0;
                    $status = $data->parcel_last_status;
                    $return_charges = 0;
                    if ($status == 6 || $status == 5 || $status == 9) {
                        if ($data->consignee_city == $data->consignor_city) {
                            $return_charges = 0;
                        } else {
                            $return_charges = $data->return_charges;
                        }
                        $payable = $data->cod_amount - $data->shipment_charges - $return_charges;
                    }
                    $amount = $data->cod_amount - $data->shipment_charges + $return_charges + $payable;
                    return $amount;
                })
                ->addColumn('handling_charges', function ($data) {
                    $handling_charges = 0;
                    $status = $data->parcel_last_status;

                    $handling_charges = DB::select("select c.min_range, c.max_range,`charges` from `charges` as `c` 
                                                        inner join `customers` as `cus` on `cus`.`id` = `c`.`customer_id` 
                                                        where `customer_id` = " . $data->consignor_id . " 
                                                        and `charges_type` = 'HandlingCharges' 
                                                        and " . $data->cod_amount . " between c.min_range and c.max_range")[0]->charges;
                    if ($status == 6 || $status == 5 || $status == 9) {
                        $handling_charges = 0;
                    }

                    return $handling_charges;
                })
                ->addColumn('pcs', function ($data) {
                    return '<input type="text" cn_no="' . $data->cn_no . '" readonly class="form_control pcs"  name="pcs"  value="1" >';
                })
                ->addIndexColumn()
                ->rawColumns(['checkbox', 'pcs', 'return_charges', 'payable', 'amount', 'handling_charges', 'DT_RowIndex'])
                ->make(true);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function addBMTempTable(Request $request)
    {
        if ($request->ajax()) {
            $validator = Validator::make($request->all(), [
                'check_all' => 'required',
                'dated' => 'required'
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }

            $date_range = $request->dated;
            if (!empty($date_range)) {
                $iparr = explode("|", trim($date_range));
                $from_date = trim($iparr[0]);
                $to_date = trim($iparr[1]);
            }

            foreach ($request->check_all as $value) {
                DB::table('temp_table')->insert([
                    'cn_no' => $value,
                    'document' => "CODBILL",
                    'consignor_id' => $request->consignor_id,
                    'from_date' => $from_date,
                    'to_date' => $to_date,
                    'user_entry' => Auth::User()->id,
                    'user_modify' => Auth::User()->id,
                    'created_at' => getCurrentDateTime(),
                    'updated_at' => getCurrentDateTime()
                ]);
            }
            return response()->json(['Bagmanifest Record Add successfully'], 200);
        }
        return 'false';
    }

    public function showCodTempRecord()
    {
        try {
            $this->x = 0;
            $this->i = 0;
            $temp_table = DB::table('temp_table')->where('user_entry', Auth::User()->id)->where('document', "CODBILL")->get();
            $paid_daily_collection = DB::table('paid_cod_daily_collection')->selectRaw('SUM(amount) AS cod_collection_amount')->where('consignor_id', $temp_table[0]->consignor_id)->where('status', 0)->get();
            $this->advance_amount = $paid_daily_collection[0]->cod_collection_amount;


            $codbill = DB::table('shipment_booking as sb')
                ->join('customers as cus', 'cus.id', '=', 'sb.consignor_id')
                ->join('city as c_city', 'c_city.id', '=', 'sb.consignor_city')
                ->join('city', 'city.id', '=', 'sb.consignee_city')
                ->join('services as s', 's.id', '=', 'sb.service_id')
                ->join('shipment_status as ss', 'ss.status_id', '=', 'sb.parcel_last_status')
                ->where('sb.parcel_last_status', '!=', '')
                ->where('sb.parcel_last_status', '!=', '1')
                ->where('sb.is_codbill', '=', '0')
                ->where('sb.is_delete', '=', '0')
                ->whereIn('sb.id', DB::table('temp_table')->where('document', '=', 'CODBILL')->pluck('cn_no'))
                ->orderBy('sb.pickup_date', 'asc')
                ->select(
                    'sb.id as cn_no',
                    's.id as service_id',
                    's.service_name',
                    'sb.booking_date',
                    'sb.pickup_date',
                    'sb.customer_type',
                    'sb.consignee_name',
                    'sb.consignee_city',
                    'sb.parcel_actual_weight',
                    'sb.consignor_id',
                    'sb.cod_amount',
                    'city.name as destination',
                    'cus.customer_name',
                    'c_city.name as consignor_city',
                    'c_city.id as orign',
                    'sb.shipment_charges',
                    'ss.status_name',
                    'cus.return_charges',
                    'sb.parcel_last_status',
                    'cus.fuel_surcharge',
                    'cus.picking_paking'
                )->get();
            $this->count = count($codbill);
            return DataTables::of($codbill)
                ->addColumn('checkbox', function ($data) {
                    $this->a++;
                    return '<input type="checkbox" class="chk_del"  name="chk_del_' . $this->a . '" value="' . $data->cn_no . '" >';
                })
                ->addColumn('return_charges', function ($data) {
                    $status = $data->parcel_last_status;
                    $return_charges = 0;
                    if ($status == 6 || $status == 5 || $status == 9) {
                        if ($data->consignee_city == $data->consignor_city) {
                            $return_charges = 0;
                        } else {
                            $return_charges = $data->return_charges;
                        }
                    }
                    return $return_charges;
                })
                ->addColumn('payable', function ($data) {
                    $payable = 0;
                    $status = $data->parcel_last_status;
                    $return_charges = 0;
                    if ($status == 6 || $status == 5 || $status == 9) {
                        if ($data->consignee_city == $data->consignor_city) {
                            $return_charges = 0;
                        } else {
                            $return_charges = $data->return_charges;
                        }
                        $payable = $data->cod_amount - $data->shipment_charges - $return_charges;
                    }
                    return $payable;
                })
                ->addColumn('amount', function ($data) {
                    $payable = 0;
                    $status = $data->parcel_last_status;
                    $return_charges = 0;
                    if ($status == 6 || $status == 5 || $status == 9) {
                        if ($data->consignee_city == $data->consignor_city) {
                            $return_charges = 0;
                        } else {
                            $return_charges = $data->return_charges;
                        }
                        $payable = $data->cod_amount - $data->shipment_charges - $return_charges;
                    }
                    $amount = $data->cod_amount - $data->shipment_charges + $return_charges + $payable;
                    $this->x++;
                    return $amount . '<input type="hidden" name="totalnum" value="' . $this->count . '" />
                <input type="hidden" name="consignee_name_' . $this->x . '"  value="' . $data->consignee_name . '" />
                <input type="hidden" name="pickup_date_' . $this->x . '"  value="' . $data->pickup_date . '" />
                <input type="hidden" name="consignor_name_' . $this->x . '"  value="' . $data->customer_name . '" />
                <input type="hidden" name="consignor_id_' . $this->x . '"  value="' . $data->consignor_id . '" />
                <input type="hidden" name="weight_' . $this->x . '" id="weight' . $this->x . '" value="' . $data->parcel_actual_weight . '" />
                <input type="hidden" name="orign_' . $this->x . '"  value="' . $data->orign . '" />
                <input type="hidden" name="destination_' . $this->x . '"  value="' . $data->consignee_city . '" />
                <input type="hidden" name="cod_amount_' . $this->x . '" id="cod_amount' . $this->x . '" value="' . $data->cod_amount . '" />
                <input type="hidden" name="shipment_charges_' . $this->x . '" id="shipment_charges' . $this->x . '" value="' . $data->shipment_charges . '" />
                <input type="hidden" name="return_charges_' . $this->x . '" id="return_charges' . $this->x . '" value=" ' . $return_charges . '" />
                <input type="hidden" name="recivable_' .  $this->x . '" id="recivable' . $this->x . '" value="' . $payable . '">
                <input type="hidden" name="amount_' .  $this->x . '" id="amount' . $this->x . '" value="' . $amount . '">
                <input type="hidden" name="status_' . $this->x . '" value=" ' . $status . '" />
                <input type="hidden" name="service_type_' . $this->x . '" value="' . $data->service_id . '" />
                <input type="hidden" name="advance_amount_' . $this->i . '" value="' . $this->advance_amount . '" />';
                })
                ->addColumn('handling_charges', function ($data) {
                    $this->i++;
                    $handling_charges = 0;
                    $status = $data->parcel_last_status;

                    $handling_charges = DB::select("select c.min_range, c.max_range,`charges` from `charges` as `c` 
                                                    inner join `customers` as `cus` on `cus`.`id` = `c`.`customer_id` 
                                                    where `customer_id` = " . $data->consignor_id . " 
                                                    and `charges_type` = 'HandlingCharges' 
                                                    and " . $data->cod_amount . " between c.min_range and c.max_range")[0]->charges;
                    if ($status == 6 || $status == 5 || $status == 9) {
                        $handling_charges = 0;
                    }


                    $flyer_query = DB::select("select (sum(c.medium_qty * cs.flyer_charges_medium)+sum(c.large_qty * cs.flyer_charges_large)+sum(c.xlarge_qty * cs.flyer_charges_xlarge)) TotalFlyerChg,sum(c.medium_qty+c.large_qty+c.xlarge_qty) TotalFlyer
                from customers cs inner join charges c on c.customer_id = cs.id
                where c.status='1' and cs.id='" . $data->consignor_id . "' and c.charges_type='FlyerCharges' ");

                    $box_query = DB::select("select (sum(c.medium_qty * cs.box_charges_medium)+sum(c.large_qty * cs.box_charges_large)+sum(c.xlarge_qty * cs.box_charges_xlarge)) TotalBoxChg,sum(c.medium_qty+c.large_qty+c.xlarge_qty) TotalBox
                from customers cs inner join charges c on c.customer_id = cs.id
                where c.status='1' and cs.id='" . $data->consignor_id . "' and c.charges_type='BoxCharges' ");


                    $picking_paking_query = DB::select("select sum(c.charges+cs.picking_paking) picking_paking,sum(cs.picking_paking) total_picking_paking
                from customers cs inner join charges c on c.customer_id = cs.id
                where c.status='1' and cs.id='" . $data->consignor_id . "' and c.charges_type='PickAndPackCharges' ");

                    return $handling_charges . '<input type="hidden" name="handling_charges_' . $this->i . '" id="handling_charges' . $this->i . '" value="' . $handling_charges . '" />
                <input type="hidden" name="fuel_surcharge_' . $this->i . '" id="fuel_surcharge' . $this->i . '" value="' . $data->fuel_surcharge . '">
                <input type="hidden" name="picking_paking_' . $this->i . '" id="picking_paking' . $this->i . '" value="' . $picking_paking_query[0]->picking_paking . '">
                <input type="hidden" name="total_picking_paking_' . $this->i . '" id="total_picking_paking' . $this->i . '" value="' . $picking_paking_query[0]->total_picking_paking . '">

                <input type="hidden" name="flyer_charges_' . $this->i . '" id="flyer_charges' . $this->i . '" value="' . $flyer_query[0]->TotalFlyerChg . '">
                <input type="hidden" name="total_flyer_' . $this->i . '" id="total_flyer' . $this->i . '" value="' . $flyer_query[0]->TotalFlyer . '">

                <input type="hidden" name="box_charges_' . $this->i . '" id="box_charges' . $this->i . '" value="' . $box_query[0]->TotalBoxChg . '">
                <input type="hidden" name="total_box_' . $this->i . '" id="total_box' . $this->i . '" value="' . $box_query[0]->TotalBox . '">';
                })
                ->addIndexColumn()
                ->rawColumns(['checkbox', 'return_charges', 'payable', 'amount', 'handling_charges', 'DT_RowIndex'])
                ->make(true);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function addCod(Request $request)
    {
        if ($request->ajax()) {
            $validator = Validator::make($request->all(), [
                'consignor_id_1' => 'required|numeric',
                'consignor_name_1' => 'required',
                'total_cod_amount' => 'nullable|numeric',
                'fuel_charges' => 'nullable|numeric',
                'total_flyer' => 'nullable|numeric',
                'total_flyer_charges' => 'nullable|numeric',
                'total_box' => 'nullable|numeric',
                'total_box_charges' => 'nullable|numeric',
                'total_pick_pack' => 'nullable|numeric',
                'total_pick_pack_charges' => 'nullable|numeric',
                'total_handling_charges' => 'nullable|numeric',
                'total_charges' => 'nullable|numeric',
                'total_return' => 'nullable|numeric',
                'totalreturn_Charges' => 'nullable|numeric',
                'other_amount' => 'nullable|numeric', //other_amount_reason
                'netamount' => 'nullable|numeric',
                // 'advance_amount' => 'nullable|required',
                'payable' => 'nullable|numeric',
                'balanceamt' => 'nullable|numeric',
            ]);

            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }

            DB::beginTransaction();

            try {

                $temp_table = DB::table('temp_table')->where('user_entry', Auth::User()->id)->where('document', "CODBILL")->get();

                if ($request->totalnum > 0) {
                    $month_name = date('M', strtotime($temp_table[0]->from_date));
                    $month_name = $month_name . date('Y-m-d');
                    $codSummary = new CodBillSummary;
                    $codSummary->consignor_id = $request->consignor_id_1;
                    $codSummary->consignor_name = $request->consignor_name_1;
                    $codSummary->month_name = $month_name;
                    $codSummary->from_date = $temp_table[0]->from_date;
                    $codSummary->to_date = $temp_table[0]->to_date;
                    $codSummary->total_cod_amount = $request->total_cod_amount;
                    $codSummary->total_charges = $request->total_charges;
                    $codSummary->total_return_amound = $request->total_return;
                    $codSummary->total_return_charges = $request->totalreturn_Charges;
                    $codSummary->fuel_charges = $request->fuel_charges;
                    $codSummary->total_handling_charges = $request->total_handling_charges;
                    $codSummary->total_flyer = $request->total_flyer;
                    $codSummary->total_flyer_charges = $request->total_flyer_charges;
                    $codSummary->total_box = $request->total_box;
                    $codSummary->total_box_charges = $request->total_box_charges;
                    $codSummary->total_pick_pack = $request->total_pick_pack;
                    $codSummary->total_pick_pack_charges = $request->total_pick_pack_charges;
                    $codSummary->netamount = $request->netamount;
                    $codSummary->other_amount = $request->other_amount;
                    $codSummary->other_amount_reason = $request->other_amount_reason;
                    $codSummary->advance_amount = $request->advance_amount;
                    $codSummary->payable = $request->payable;
                    $codSummary->mode = $request->mode;
                    $codSummary->balanceamt = $request->balanceamt;
                    $codSummary->user_entry = Auth::User()->id;
                    $codSummary->user_modify = Auth::User()->id;
                    $codSummary->save();
                }


                $i = 1;
                $exist = "N";
                while ($i <= $request->totalnum) {
                    if (!empty($request->post('chk_del_' . $i))) {
                        $exist = "Y";
                        $codDetail = new CodBillDetail;
                        $codDetail->cod_bill_id = $codSummary->id;
                        $codDetail->cn_no = $request->post('chk_del_' . $i);
                        $codDetail->weight = $request->post('weight_' . $i);
                        $codDetail->consignee_name = $request->post('consignee_name_' . $i);
                        $codDetail->orign = $request->post('orign_' . $i);
                        $codDetail->destination = $request->post('destination_' . $i);
                        $codDetail->cod_amount = $request->post('cod_amount_' . $i);
                        $codDetail->delivery_charges = $request->post('shipment_charges_' . $i);
                        $codDetail->return_Charges = $request->post('return_charges_' . $i);
                        $codDetail->recivable = $request->post('recivable_' . $i);
                        $codDetail->amount = $request->post('amount_' . $i);
                        $codDetail->service_type = $request->post('service_type_' . $i);
                        $codDetail->status = $request->post('status_' . $i);
                        $codDetail->handling_charges = $request->post('handling_charges_' . $i);
                        $codDetail->pickup_date = $request->post('pickup_date_' . $i);
                        $codDetail->user_entry = Auth::User()->id;
                        $codDetail->user_modify = Auth::User()->id;
                        $codDetail->save();

                        $booking = Booking::findOrFail($request->post('chk_del_' . $i));
                        $booking->is_codbill  = 1;
                        $booking->user_modify = Auth::User()->id;
                        $booking->update();

                        DB::table('charges')
                            ->where('charges_type', 'FlyerCharges')
                            ->where('customer_id', $request->consignor_id_1)
                            ->update(['status' => '1']);

                        DB::table('charges')
                            ->where('charges_type', 'BoxCharges')
                            ->where('customer_id', $request->consignor_id_1)
                            ->update(['status' => '1']);
                    }
                    $i++;
                }


                if ($exist == "Y") {
                    DB::table('paid_cod_daily_collection')
                        ->where('consignor_id', $request->consignor_id_1)
                        ->update(['status' => '1']);

                    DB::table('paid_cod_daily_collection')->insert([
                        'date' => date('Y-m-d H:i:s'),
                        'consignor_id' => $request->consignor_id_1,
                        'bill_number' => $codSummary->id,
                        'bill_amount' => $request->netamount,
                        'payable_amound_bill' => $request->payable,
                        'advance_amount' => $request->advance_amount,
                        'amount' => $request->balanceamt,
                        'comments' => "Advance Amount",
                        'user_entry' => Auth::User()->id,
                        'user_modify' => Auth::User()->id,
                        'created_at' => getCurrentDateTime(),
                        'updated_at' => getCurrentDateTime()
                    ]);
                }

                DB::table('temp_table')
                    ->where('user_entry', Auth::User()->id)
                    ->where('document', "CODBILL")->delete();

                DB::commit();
                return response()->json(['success' => 'data is successfully updated'], 200);
            } catch (\Exception $e) {
                // An error occurred, rollback the transaction
                DB::rollback();
            }
        }
        //return 'false';
    }

    //report section  start
    public function CodBillReport()
    {
        $customer = customer::where('status', 1)->get();
        return view('admin.codbill.report')->with(compact('customer'));
    }

    public function getBillingMonths($consignor_id)
    {
        try {
            $months = CodBillSummary::select('id as cod_bill_id', 'month_name')->where('consignor_id', $consignor_id)->get();
            $msg['billing_month'] = $months->toJson();
            return response()->json(['success' => 'successfull retrieve data', $msg], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function getBillingMonthDate($consignor_id, $month_name)
    {
        try {
            $months = CodBillSummary::select('from_date', 'to_date')->where('consignor_id', $consignor_id)->where('id', $month_name)->get();
            $msg['billing_month'] = $months->toJson();
            return response()->json(['success' => 'successfull retrieve data', $msg], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function getCodBillReport($consignor_id, $month_name)
    {
        try {
            $getreportdetail = DB::table('codbill_detail AS cd')
                ->select('cd.cod_bill_id', 'cd.cn_no', 'cd.pickup_date', 'cd.weight', 'cd.orign', 'cd.destination', 'cd.cod_amount', 'cd.delivery_charges', 'cd.return_Charges', 'cd.recivable', 'cd.amount', 'cd.service_type', 'cd.status', 'cd.handling_charges', 'c.name AS destination_name', 'ss.status_name', 'services.service_name')
                ->join('codbill_summary AS cs', 'cs.id', '=', 'cd.cod_bill_id')
                ->join('city AS c', 'c.id', '=', 'cd.destination')
                ->join('services', 'services.id', '=', 'cd.service_type')
                ->join('shipment_status AS ss', 'ss.status_id', '=', 'cd.status')
                ->where('cs.consignor_id', $consignor_id)
                ->where('cd.cod_bill_id', $month_name)
                ->get();

            $html = "";
            $html .= '<table width="100%" class="table table-bordered">
                        <thead>
                            <tr>                                
                                <th>Sr No</th>
                                <th>Date</th>
                                <th>From</th>
                                <th>CN No</th>
                                <th>Weight</th>
                                <th>Destination</th>
                                <th>COD</th>
                                <th>Charges</th>
                                <th>Return Charges</th>                               
                                <th>Amount</th>
                                <th>Status</th>
                                <th>Holding Charges</th>                         
                            </tr>
                        </thead>
                        <tbody>';


            $i = 0;
            if (!empty($getreportdetail)) {
                foreach ($getreportdetail as $row) {
                    $html .= "<tr>
                                <td> " . ($i += 1) . " </td>                                                  
                                <td> " . $row->pickup_date . " </td>
                                <td> " . $row->pickup_date . " </td>
                                <td> " . $row->cn_no . " </td>
                                <td> " . $row->weight . " </td>
                                <td> " . $row->destination_name . " </td>
                                <td> " . $row->cod_amount . " </td>
                                <td> " . $row->delivery_charges . " </td>
                                <td> " . $row->return_Charges . " </td>
                                <td> " . $row->amount . " </td>                                
                                <td> " . $row->status_name . " </td>                                
                                <td> " . $row->handling_charges . " </td>                                                                                   
                            </tr>";
                }
            }

            $html .= '</tbody></table></div>';


            $query_summary = DB::table('codbill_summary as cs')
                ->select(
                    'cs.consignor_id',
                    'cs.consignor_name',
                    'cs.total_cod_amount',
                    'cs.total_charges',
                    'cs.total_return_amound',
                    'cs.total_return_charges',
                    'cs.fuel_charges',
                    'cs.total_handling_charges',
                    'cs.total_flyer',
                    'cs.total_flyer_charges',
                    'cs.total_pick_pack',
                    'cs.total_pick_pack_charges',
                    'cs.netamount',
                    'cs.other_amount',
                    'cs.other_amount_reason',
                    'cs.advance_amount',
                    'cs.payable',
                    'cs.mode',
                    'cs.balanceamt'
                )
                ->where('cs.consignor_id', $consignor_id)
                ->where('cs.id',  $month_name)
                ->get();

            if (!empty($query_summary)) {
                $html .= '<div class="row">                
                <div class="col-md-3">
                    <div class="form-group">
                        <label>Total COD Amount :</label>   
                        <label>' . (isset($query_summary[0]->total_cod_amount) ? $query_summary[0]->total_cod_amount : "") . '</label>   
                    </div>
                    <!-- /.form group -->
                </div>
                <div class="col-md-3">
                    <!-- Date range -->
                    <div class="form-group">
                        <label>Fuel Surcharge :</label>
                        <label>' . (isset($query_summary[0]->fuel_charges) ? $query_summary[0]->fuel_charges : "") . '</label>   
                    </div>
                    <!-- /.form group -->
                </div>

                <div class="col-md-3">
                    <div class="form-group">
                        <label>Flyer Charges :</label>       
                        <label>' . (isset($query_summary[0]->total_flyer_charges) ? $query_summary[0]->total_flyer_charges : "") . '</label>   
                    </div>
                    <!-- /.form group -->
                </div>

                <div class="col-md-3">
                    <div class="form-group">
                        <label>Pick & Pack Charges :</label>
                        <label>' . (isset($query_summary[0]->total_pick_pack_charges) ? $query_summary[0]->total_pick_pack_charges : "") . '</label>   
                    </div>
                    <!-- /.form group -->
                </div>
            </div>
            <div class="row">  
                <div class="col-md-3">
                    <div class="form-group">
                        <label>handling charges :</label>
                        <label>' . (isset($query_summary[0]->total_handling_charges) ? $query_summary[0]->total_handling_charges : "") . '</label>   
                    </div>
                    <!-- /.form group -->
                </div>
                <div class="col-md-3">
                    <div class="form-group">
                        <label>Delivery Charges  :</label>
                        <label>' . (isset($query_summary[0]->total_charges) ? $query_summary[0]->total_charges : "") . '</label>   
                    </div>
                    <!-- /.form group -->
                </div>
                <div class="col-md-3">
                    <div class="form-group">
                        <label>Return :</label>
                        <label>' . (isset($query_summary[0]->total_return_amound) ? $query_summary[0]->total_return_amound : "") . '</label>   
                    </div>
                    <!-- /.form group -->
                </div>
                <div class="col-md-3">
                    <div class="form-group">
                        <label>Charges Return :</label>
                        <label>' . (isset($query_summary[0]->total_return_charges) ? $query_summary[0]->total_return_charges : "") . '</label>   
                    </div>
                    <!-- /.form group -->
                </div>
            </div>
            <div class="row">  
                <div class="col-md-3">
                    <div class="form-group">
                        <label>Other Charges :</label>
                        <label>' . (isset($query_summary[0]->other_amount) ? $query_summary[0]->other_amount : "0") . '</label>
                        <br><label>(' . (isset($query_summary[0]->other_amount_reason) ? $query_summary[0]->other_amount_reason : "") . ')</label>   
                    </div>
                    <!-- /.form group -->
                </div>
                <div class="col-md-3">
                    <div class="form-group">
                        <label>Net Amount Payable :</label>
                        <label>' . (isset($query_summary[0]->netamount) ? $query_summary[0]->netamount : "") . '</label>   
                    </div>
                    <!-- /.form group -->
                </div>
                <div class="col-md-3">
                    <div class="form-group">
                        <label>Advance Amount: </label>
                        <label>' . (isset($query_summary[0]->advance_amount) ? $query_summary[0]->advance_amount : "0") . '</label>   
                    </div>
                    <!-- /.form group -->
                </div>
                <div class="col-md-3">
                    <div class="form-group">
                        <label>Paid Amount :</label>
                        <label>' . (isset($query_summary[0]->payable) ? $query_summary[0]->payable : "0") . '</label>   
                    </div>
                    <!-- /.form group -->
                </div>
            </div>
            <div class="row">  
                <div class="col-md-3">
                    <div class="form-group">
                        <label>Balance Amount :</label>
                        <label>' . (isset($query_summary[0]->balanceamt) ? $query_summary[0]->balanceamt : "0") . '</label>   
                    </div>
                    <!-- /.form group -->
                </div>
                <div class="col-md-3">
                    <div class="form-group">
                        <label>Mode :</label>
                        <label>' . (isset($query_summary[0]->mode) ? $query_summary[0]->mode : "N/A") . '</label>   
                    </div>
                    <!-- /.form group -->
                </div
            </div>';
            }

            $msg['report_table'] = $html;
            return response()->json(['success' => 'successfull retrieve data', $msg], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    //report close
}
