<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\CountryModel;
use Illuminate\Support\Facades\Validator;
use Yajra\DataTables\Facades\DataTables as DataTables;
use Illuminate\Validation\Rule;
class CountryController extends Controller
{
    public function index()
    {
        return view('admin.country.index');
    }

    public function create()
    {
        try {
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }
    public function store(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'name' => 'required|unique:country',
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }
            $status = 0;
            if($request->post('status') == "on")
            {
                $status = 1;
            }

            CountryModel::create([
                'name' => $request->post('name'),                
                'status' => $status,
                'user_entry' => \Auth::User()->id,
                'user_modify' => \Auth::User()->id
            ]);
            return response()->json(['success' => 'data is successfully updated'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function show($id)
    {
        try {
            $country = CountryModel::select(['id', 'name','status']);
            return DataTables::of($country)
                ->addColumn('action', function ($data) {
                    return table_edit_delete_button($data->id, 'country');
                })
                ->addColumn('checkbox', function ($data) {
                    return checkbox_show($data->id);
                })
                ->editColumn('status', function ($data) {
                    return current_status($data->status);
                })           
                ->addIndexColumn()
                ->rawColumns(['action', 'checkbox', 'status','DT_RowIndex'])
                ->make(true);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function edit($id)
    {
        try {
            $country = CountryModel::find($id);
            return response()->json(['success' => 'successfull retrieve data', 'data' => $country->toJson()], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function rec_update(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'country_id' => 'required',
                'name' => [
                    'required',
                    Rule::unique('country')->ignore($request->country_id),
                ],
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }
            $status = 0;
            if($request->status == "on")
            {
                $status = 1;
            }
            $country = CountryModel::findOrFail($request->country_id);                                               
            $country->name = $request->name;           
            $country->status = $status;
            $country->user_modify = \Auth::User()->id;
            $country->update();
            return response()->json(['success' => 'data is successfully updated'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function destroy($id)
    {
        try {
            $country = CountryModel::find($id);
            $country->delete();
            return response()->json(['success' => 'data is successfully deleted'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function deleteAll(Request $request)
    {
        if ($request->ajax()) {
            $validator = Validator::make($request->all(), [
                'check_all' => 'required'
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }

            foreach ($request->check_all as $value) {
                CountryModel::where('id', $value)->delete();
            }
            return response()->json(['success' => 'data is successfully deleted'], 200);
        }
        return 'false';
    }
}
