<?php

namespace App\Http\Controllers\admin;
use App\Http\Controllers\Controller;
use App\Models\Role;
use App\Models\RolePermission;
use App\Models\Module;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;
class RoleController extends Controller
{    
    public function index()
    {
        $roles = Role::orderBy('id','DESC')->get();
        return view('admin/role/index')->with(compact('roles'));   
    }

    public function create()
    {
        $modules = Module::orderBy('id','DESC')->get();        
        return view('admin/role/create')->with(compact('modules'));  
    }
    
    public function store(Request $request)
    {      
    
        $validator = Validator::make($request->all(), [           
            'name' => [
                'required',
                'regex:/(^[-0-9A-Za-z.,\/ ]+$)/',
                Rule::unique('role'),
            ],            
        ]);

        if ($validator->fails()) {            
            $errors = $validator->errors()->all();
            $modules = Module::orderBy('id','DESC')->get();
            return view('admin/role/create', compact('errors','modules'));                    
        }

        $role = new Role([
            'name' => $request->get('name')
        ]);
        $role->save();
        foreach ($request->moduleid as $key => $value) {
            $role_permission = new RolePermission([
                'role_id' => $role->id,
                'module_id' => $value,
                'pview' => isset($request->view[$key]) ? 1 : 0,
                'pcreate' => isset($request->create[$key]) ? 1 : 0,
                'pedit' => isset($request->edit[$key]) ? 1 : 0,
                'pdelete' => isset($request->delete[$key]) ? 1 : 0,
            ]);
            $role_permission->save();
        }
        return redirect('/admin/role')->with('success', 'role has been added.');
    }

    public function show($id)
    {
        //
    }
   
    public function edit($id)
    {
        $role = Role::with('permission')->findOrFail($id);
        $role->permission = json_decode($role->permission, true);
        // print_r(json_decode($role->permission, true));die;
        $modules = Module::orderBy('id','DESC')->get();       
        $errors = null; 
        return view('admin/role/edit', compact('role', 'modules','errors'));
    }

    public function update(Request $request, $id)
    {
        $validator = Validator::make($request->all(), [           
            'name' => [
                'required',
                'regex:/(^[-0-9A-Za-z.,\/ ]+$)/',
                Rule::unique('role')->ignore($id),
            ],            
        ]);

        if ($validator->fails()) {            
            $errors = $validator->errors()->all();
            $modules = Module::orderBy('id','DESC')->get();
            return view('admin.role.edit', compact('errors','modules'));                    
        }

        //print_r($request->all());die();
        $role = Role::whereId($id)->first();
        $role->name=  $request->get('name');
        $role->permission()->delete();
        $role->save();
        foreach ($request->moduleid as $key => $value) {
            $role_permission = new RolePermission([
                'role_id' => $role->id,
                'module_id' => $value,
                'pview' => isset($request->view[$key]) ? 1 : 0,
                'pcreate' => isset($request->create[$key]) ? 1 : 0,
                'pedit' => isset($request->edit[$key]) ? 1 : 0,
                'pdelete' => isset($request->delete[$key]) ? 1 : 0,
            ]);
            $role_permission->save();
        }
        return redirect('admin/role')->with('success', 'Data is successfully updated');
    }
    
    public function destroy($id)
    {
        $dept = Role::where('id', $id);

        // $dept = Department::findOrFail($id);
        $dept->delete();
        return redirect('admin/role')->with('success', 'Data is successfully deleted');
    }
}