<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use App\Models\Branch;
use App\Models\Route;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Yajra\DataTables\Facades\DataTables;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;
class RouteController extends Controller
{
    public function index()
    {
        $branches = Branch::where('status', 1)->get();
        return view('admin.route.index')->with(compact('branches'));
    }

    public function create()
    {
        try {
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }
    public function store(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'branch_id' => 'required',                
                'route_name' => [
                    'required',
                    Rule::unique('routes')
                ],
            ]);
            if ($validator->fails()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }
            
            $status = $request->has('status') ? 1 : 0;

            Route::create([
                'branch_id' => $request->post('branch_id'),                
                'route_name' => $request->post('route_name'),                
                'status' => $status,
                'user_entry' => auth()->user()->id,
                'user_modify' => auth()->user()->id,
            ]);
            return response()->json(['success' => 'data is successfully updated'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function show($id)
    {
        try {
            $route = DB::table('routes as r')
                ->join('branch as b', 'b.id', '=', 'r.branch_id')                
                ->select('r.id','r.route_name','r.status','b.name as branch_name')->get();
            return DataTables::of($route)
                ->addColumn('action', function ($data) {
                    return table_edit_delete_button($data->id, 'route');
                })
                ->addColumn('checkbox', function ($data) {
                    return checkbox_show($data->id);
                })
                ->editColumn('status', function ($data) {
                    return current_status($data->status);
                })               
                ->addIndexColumn()
                ->rawColumns(['action', 'checkbox', 'status','DT_RowIndex'])
                ->make(true);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function edit($id)
    {
        try {
            $route = Route::find($id);
            return response()->json(['success' => 'successfull retrieve data', 'data' => $route->toJson()], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function rec_update(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'id' => 'required',
                'branch_id' => 'required',
                'route_name' => [
                    'required',
                    'regex:/(^[-0-9A-Za-z.,\/ ]+$)/',
                    Rule::unique('routes')->ignore($request->id),
                ]
            ]);
            if ($validator->fails()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }

            $status = $request->has('status') ? 1 : 0;
            
            $route = Route::findOrFail($request->id);                                               
            $route->branch_id = $request->branch_id;           
            $route->route_name = $request->route_name;           
            $route->status = $status;
            $route->user_modify = auth()->user()->id;
            $route->update();
            return response()->json(['success' => 'data is successfully updated'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function destroy($id)
    {
        try {
            $country = Route::find($id);
            $country->delete();
            return response()->json(['success' => 'data is successfully deleted'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function deleteAll(Request $request)
    {
        if ($request->ajax()) {
            $validator = Validator::make($request->all(), [
                'check_all' => 'required'
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }

            foreach ($request->check_all as $value) {
                Route::where('id', $value)->delete();
            }
            return response()->json(['success' => 'data is successfully deleted'], 200);
        }
        return 'false';
    }
}
