<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use App\Models\CityModel;
use App\Models\CountryModel;
use App\Models\Designation;
use App\Models\Staff;
use Illuminate\Http\Request;
use Yajra\DataTables\Facades\DataTables;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;

class StaffController extends Controller
{
    public function index()
    {
        $designation = Designation::get();
        $countries = CountryModel::where('status', 1)->get();
        $cities = CityModel::where('status', 1)->get();
        return view('admin.staff.index')->with(compact('countries','cities','designation'));
    }

    public function create()
    {
        try {
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }
    public function store(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'staff_name' => 'required|unique:staff',                
                'designation_id' => 'required',     
                'mobile_number' => 'required|min:11',                   
                'email' => 'required|email',                      
                'country_id' => 'required',                         
                'city_id' => 'required',                         
                'address' => 'required',                         
                'nic' => 'required|min:13|max:15',           
                'reference' => 'required',                         
                'salary' => 'required|numeric',
                'qualification' => 'required',
                'previous_company' => 'required',     
                'previous_job_expererence' => 'required',   
            ]);

            if ($validator->fails()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }
            
            $status = $request->has('status') ? 1 : 0;

            Staff::create([
                'staff_name' => $request->post('staff_name'),                
                'designation_id' => $request->post('designation_id'),                
                'mobile_number' => $request->post('mobile_number'),                
                'email' => $request->post('email'),                
                'country_id' => $request->post('country_id'),                
                'city_id' => $request->post('city_id'),                
                'address' => $request->post('address'),                
                'nic' => $request->post('nic'),                
                'reference' => $request->post('reference'),
                'salary' => $request->post('salary'),
                'qualification' => $request->post('qualification'),
                'previous_job_expererence' => $request->post('previous_job_expererence'),
                'previous_company' => $request->post('previous_company'),
                'status' => $status,
                'user_entry' => \Auth::User()->id,
                'user_modify' => \Auth::User()->id
            ]);
            return response()->json(['success' => 'data is successfully updated'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function show($id)
    {
        try {
            $servie = Staff::select(['id', 'staff_name','mobile_number']);
            return DataTables::of($servie)
                ->addColumn('action', function ($data) {
                    return table_edit_delete_button($data->id, 'staff');
                })
                ->addColumn('checkbox', function ($data) {
                    return checkbox_show($data->id);
                })
                ->editColumn('status', function ($data) {
                    return current_status($data->status);
                })               
                ->addIndexColumn()
                ->rawColumns(['action', 'checkbox', 'status','DT_RowIndex'])
                ->make(true);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function edit($id)
    {
        try {
            $staff = Staff::find($id);
            return response()->json(['success' => 'successfull retrieve data', 'data' => $staff->toJson()], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function rec_update(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'id' => 'required',                
                'staff_name' => [
                    'required',
                    'regex:/(^[-0-9A-Za-z.,\/ ]+$)/',
                    Rule::unique('staff')->ignore($request->id),
                ],
                'designation_id' => 'required',     
                'mobile_number' => 'required',                         
                'email' => 'required',                         
                'country_id' => 'required',                         
                'city_id' => 'required',                         
                'address' => 'required',                         
                'nic' => 'required',                         
                'reference' => 'required',                         
                'salary' => 'required',         
                'qualification' => 'required',                             
                'previous_company' => 'required',     
                'previous_job_expererence' => 'required',          
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }
            $status = 0;
            if($request->status == "on")
            {
                $status = 1;
            }
            $staff = Staff::findOrFail($request->id);                                               
            $staff->staff_name = $request->staff_name;           
            $staff->designation_id = $request->designation_id;                     
            $staff->mobile_number = $request->mobile_number;   
            $staff->email = $request->email;   
            $staff->country_id = $request->country_id;   
            $staff->city_id = $request->city_id;
            $staff->address = $request->address;
            $staff->nic = $request->nic;
            $staff->reference = $request->reference;
            $staff->qualification = $request->qualification;
            $staff->previous_job_expererence = $request->previous_job_expererence;
            $staff->previous_company = $request->previous_company;
            $staff->user_modify = \Auth::User()->id;
            $staff->update();
            return response()->json(['success' => 'data is successfully updated'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function destroy($id)
    {
        try {
            $servie = Staff::find($id);
            $servie->delete();
            return response()->json(['success' => 'data is successfully deleted'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function deleteAll(Request $request)
    {
        if ($request->ajax()) {
            $validator = Validator::make($request->all(), [
                'check_all' => 'required'
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }

            foreach ($request->check_all as $value) {
                Staff::where('id', $value)->delete();
            }
            return response()->json(['success' => 'data is successfully deleted'], 200);
        }
        return 'false';
    }    
}
