<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use App\Models\Branch;
use App\Models\Role;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Yajra\DataTables\Facades\DataTables;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule;

class UserController extends Controller
{
    public function index()
    {
        $roles = Role::get();
        $branches = Branch::where('status', 1)->get();
        return view('admin.user.index')->with(compact('roles', 'branches'));
    }

    public function create(Request $request)
    {
    }
    public function store(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'user_name' => 'required|unique:users',
                'email' => 'required',
                'password' => 'required',
                'role_id' => 'required',
                'status' => 'required'
            ]);
            if ($validator->fails()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }
            // $file = $request->file('user_image');
            // $location = 'uploads/user';
            // $data = upload_images($file, $location);
            // if ($data['success'] == 1) {

            $status = 0;
            if ($request->post('status') == "on") {
                $status = 1;
            }

            $user = new User([
                'user_name' => $request->post('user_name'),
                'email' => $request->post('email'),
                'cno_from' => $request->post('cno_from'),
                'cno_to' => $request->post('cno_to'),
                'current' => $request->post('cno_from'),
                'branch_id' => $request->post('branch_id'),
                'password' => Hash::make('password'),
                'role_id' => $request->post('role_id'),
                'status' => $status,
                'user_entry' => \Auth::User()->id,
                'user_modify' => \Auth::User()->id
            ]);
            $user->save();
            return response()->json(['success' => 'data is successfully added'], 200);
            // } else {
            //     return response()->json($data);
            // }
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }


    public function show($id)
    {
        try {
            $route = DB::table('users as u')
                ->join('role as r', 'r.id', '=', 'u.role_id')
                ->join('branch as b', 'b.id', '=', 'u.branch_id', 'left')
                ->select('u.*', 'r.name as role_name', 'b.name as branch_name')->get();
            return DataTables::of($route)
                ->addColumn('action', function ($data) {
                    return table_edit_delete_button($data->id, 'user');
                })
                ->addColumn('checkbox', function ($data) {
                    return checkbox_show($data->id);
                })
                ->editColumn('status', function ($data) {
                    return current_status($data->status);
                })
                ->addIndexColumn()
                ->rawColumns(['action', 'checkbox', 'status','DT_RowIndex'])
                ->make(true);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function edit($id)
    {
        try {
            $user = User::find($id);
            return response()->json(['success' => 'successfull retrieve data', 'data' => $user->toJson()], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function rec_update(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'id' => 'required',
                'user_name' => [
                    'required',
                    'regex:/(^[-0-9A-Za-z.,\/ ]+$)/',
                    Rule::unique('users')->ignore($request->id),
                ],
                'email' => 'required|email',
                'cno_from' => 'required|numeric',
                'cno_to' => 'required|numeric',                
                'role_id' => 'required',
                'status' => 'required',
                'user_image' => 'nullable|image|mimes:jpeg,png,jpg,gif|max:2048',
            ]);

            if ($validator->fails()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }


            if ($request->pass_chk == "Y") {
                $validator = Validator::make($request->all(), [
                    // ... your other validation rules ...
                    'password' => 'required',
                ]);
            
                if ($validator->fails()) {
                    return response()->json(['error' => $validator->errors()->all()]);
                }                           
            }

            $user = User::findOrFail($request->id);

            if ($request->hasFile('user_image')) {
                $file = $request->file('user_image');
                $filePath = $file->store('uploads/user');
                $user->user_image = $filePath;
            }

            if ($request->pass_chk == "Y") {
                $user->password = $request->password;
            }

            $status = 0;
            if ($request->post('status') == "on") {
                $status = 1;
            }

            $user->user_name = $request->user_name;
            $user->email = $request->email;
            $user->status = $status;
            $user->cno_from = $request->cno_from;
            $user->cno_to = $request->cno_to;
            $user->current = $request->cno_from;
            $user->branch_id = $request->branch_id;
            $user->role_id = $request->role_id;
            $user->user_modify = auth()->user()->id;
            $user->update();

            return response()->json(['success' => 'Data is successfully updated'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function destroy($id)
    {
        try {
            $user = User::find($id);
            $user->delete();
            return response()->json(['success' => 'data is successfully deleted'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function deleteAll(Request $request)
    {
        if ($request->ajax()) {
            $validator = Validator::make($request->all(), [
                'check_all' => 'required'
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }

            foreach ($request->check_all as $value) {
                User::where('id', $value)->delete();
            }
            return response()->json(['success' => 'data is successfully deleted'], 200);
        }
        return 'false';
    }

    public function trash()
    {
        $trasherdUsers = User::onlyTrashed()->latest()->paginate(3);
        return  view('admin.user.trashed')->with(compact('trasherdUsers'));
    }

    public function restore(Request $request, $id)
    {
        $trash = User::withTrashed()->find($id)->restore();
        return  redirect()->back()->with('message', 'Record Restored');
    }
}
