<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use App\Models\CityModel;
use App\Models\CountryModel;
use App\Models\Zone;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Yajra\DataTables\Facades\DataTables;
use Validator;

class ZoneController extends Controller
{
    public function index()
    {
        $countries = CountryModel::where('status', 1)->get();
        //$cities = CityModel::where('status', 1)->get();
        $cities = DB::table('city as c')->select('c.*')->whereNotIn('c.id', DB::table('zone')->pluck('city_id'))->get();
        return view('admin.zone.index')->with(compact('countries', 'cities'));
    }

    public function getCityIDs()
    {
        try {
            $cities = DB::table('city as c')->select('c.*')->whereNotIn('c.id', DB::table('zone')->pluck('city_id'))->get();
            $msg['city_list'] = $cities->toJson();
            return response()->json(['success' => 'successfull retrieve data', $msg], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function getCityEditIDs($id)
    {
        try {
            $cities = DB::table('city as c')->select('c.*')->whereNotIn('c.id', DB::table('zone')->where('id', '!=', $id)->pluck('city_id'))->get();
            $msg['city_list'] = $cities->toJson();
            return response()->json(['success' => 'successfull retrieve data', $msg], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function create()
    {
        try {
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }
    public function store(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'zone_name' => 'required|regex:/(^[-0-9A-Za-z.,\/ ]+$)/',
                'country_id' => 'required|numeric',
                'city_id' => 'required',
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }
            $status = 0;
            if ($request->post('status') == "on") {
                $status = 1;
            }

            $max = Zone::select('zone_id')->where('zone_name', $request->post('zone_name'))->first();

            if (!$max) {
                $max = Zone::max('zone_id');
                if ($max == null) {
                    $max = 1;
                } else {
                    $max++;
                }
            } else {
                $max = $max->zone_id;
            }

            if (!empty($request->city_id)) {
                foreach ($request->city_id as $city) {
                    Zone::create([
                        'zone_id' => $max,
                        'zone_name' => $request->post('zone_name'),
                        'country_id' => $request->post('country_id'),
                        'city_id' => $city,
                        'status' => $status,
                        'user_entry' => \Auth::User()->id,
                        'user_modify' => \Auth::User()->id
                    ]);
                }
            }
            return response()->json(['success' => 'data is successfully updated'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function show($id)
    {
        try {
            $zone = DB::table('zone')
                ->join('country', 'country.id', '=', 'zone.country_id')
                ->join('city', 'city.id', '=', 'zone.city_id')
                ->select('zone.*', 'country.name as country_name', 'city.name as city_name')->get();
            return DataTables::of($zone)
                ->addColumn('action', function ($data) {
                    return table_edit_delete_button($data->id, 'zone');
                })
                ->addColumn('checkbox', function ($data) {
                    return checkbox_show($data->id);
                })
                ->editColumn('status', function ($data) {
                    return current_status($data->status);
                })
                ->addIndexColumn()
                ->rawColumns(['action', 'checkbox', 'status','DT_RowIndex'])
                ->make(true);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function edit($id)
    {
        try {
            $zone = Zone::find($id);
            return response()->json(['success' => 'successfull retrieve data', 'data' => $zone->toJson()], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function rec_update(Request $request)
    {
        try {
            $validator = Validator::make($request->all(), [
                'id' => 'required',
                'zone_name' => 'required|regex:/^[\pL\s\-]+$/u',
                'country_id' => 'required|numeric',
                'citysingle' => 'required|numeric',
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }
            $status = 0;
            if ($request->status == "on") {
                $status = 1;
            }

            $max = Zone::select('zone_id')->where('zone_name', $request->post('zone_name'))->first();

            

            $zone = Zone::findOrFail($request->id);
            $zone->zone_name = $request->zone_name;
            if ($max) {
                $max = $max->zone_id;                
            }else
            {
                $max = Zone::max('zone_id');
                if ($max == null) {
                    $max = 1;
                } else {
                    $max++;
                }
            }
            $zone->zone_id =$max;
            $zone->country_id = $request->country_id;
            $zone->city_id = $request->citysingle;
            $zone->status = $status;
            $zone->user_modify = \Auth::User()->id;
            $zone->update();
            return response()->json(['success' => 'data is successfully updated'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function destroy($id)
    {
        try {
            $zone = Zone::find($id);
            $zone->delete();
            return response()->json(['success' => 'data is successfully deleted'], 200);
        } catch (\Exception $e) {
            dd($e->getMessage());
        }
    }

    public function deleteAll(Request $request)
    {
        if ($request->ajax()) {
            $validator = Validator::make($request->all(), [
                'check_all' => 'required'
            ]);
            if (!$validator->passes()) {
                return response()->json(['error' => $validator->errors()->all()]);
            }

            foreach ($request->check_all as $value) {
                Zone::where('id', $value)->delete();
            }
            return response()->json(['success' => 'data is successfully deleted'], 200);
        }
        return 'false';
    }
}
